@@ -3,7 +3,7 @@
 // extrait automatiquement de http://www.spip.net/trad-lang/
 // ** ne pas modifier le fichier **
 
-if (!defined("_ECRIRE_INC_VERSION")) return;
+if (!defined('_ECRIRE_INC_VERSION')) return;
 
 $GLOBALS[$GLOBALS['idx_lang']] = array(
 
@@ -332,7 +332,7 @@ $GLOBALS[$GLOBALS['idx_lang']] = array(
 'info_compresseur_gzip' => 'It is advisable to first check if the service provider systematically compresses PHP scripts. To do this you can, for example, use the following service: @testgzip@',
 'info_compresseur_texte' => 'If your server does not automatically compress HTML pages when sending them, you can attempt to force the compression in order to reduce the size of the pages transmitted.<b>Warning</b>: this can have a noticeable adverse effect on the performance of some servers, ',
 'info_compresseur_titre' => 'Optimisations and compression',
-'info_config_forums_prive' => 'In the editing area of the site several differnt kinds of forum may be activated:',
+'info_config_forums_prive' => 'You can activate various tupes of forums in the site\'s private area:',
 'info_config_forums_prive_admin' => 'A forum reserved for site administrators:',
 'info_config_forums_prive_global' => 'A global forum, open to all the authors:',
 'info_config_forums_prive_objets' => 'A forum attached to each article, news item, referenced site, etc.:',
@@ -792,6 +792,9 @@ in a colour indicating their status:',
 'jour_non_connu_nc' => 'unknown',
 
 // L
+'ldap_correspondance' => 'inherit field @champ@',
+'ldap_correspondance_1' => 'Inherit LDAP fields',
+'ldap_correspondance_2' => 'For each of the following SPIP fields, enter the name of the corresponding LDAP field. Leave it blank if you don\'t wanted it filled, separate with spaces or commas to try several LDAP fields.',
 'lien_ajout_destinataire' => 'Add this recipient',
 'lien_ajouter_auteur' => 'Add this author',
 'lien_ajouter_participant' => 'Add a participant',
@@ -835,7 +838,7 @@ in a colour indicating their status:',
 'mois_non_connu' => 'unknown',
 
 // N
-'nouvelles_versions' => 'New versions of SPIP are available',
+'nouvelle_version_spip' => 'SPIP version @version@ is available',
 
 // O
 'onglet_contenu' => 'Contents',
@@ -846,19 +849,6 @@ in a colour indicating their status:',
 'onglet_proprietes' => 'Properties',
 'onglet_repartition_actuelle' => 'now',
 'onglet_sous_rubriques' => 'Sub-sections',
-'ortho_ajouter_ce_mot' => 'Add this word to the dictionary',
-'ortho_aucune_suggestion' => 'No suggestion was found for this word.',
-'ortho_avis_privacy' => 'Spip contains a spell checker. However, before enabling it, please read the following paragraph carefully:',
-'ortho_avis_privacy2' => 'In order to check the spelling of a text, the site will send the list of words to be checked to an external "spelling server", which people of the Spip community have made available. The words are mixed up before being sent in order to maintain some level of confidentiality. If you are concerned about your data, do not activate this option (and withdraw all your information from the web at once).',
-'ortho_ce_mot_connu' => 'This word is in the site\'s dictionary.',
-'ortho_dico_absent' => 'No dictionary was found for this language',
-'ortho_mode_demploi' => 'Urecognised words have been highlighted in red. Click on these words to see suggested corrections.',
-'ortho_mots_a_corriger' => 'words to correct',
-'ortho_orthographe' => 'Spelling',
-'ortho_supprimer_ce_mot' => 'Remove this word from the dictionary',
-'ortho_trop_de_fautes' => 'Your text contains too many mistakes! In order to avoid overloading the system, no corrections have been suggested.',
-'ortho_verif_impossible' => 'The system cannot check the spelling of this text.',
-'ortho_verifier' => 'Spell check',
 
 // P
 'page_pas_proxy' => 'This page shouldn\'t go through the proxy',
@@ -1051,7 +1041,7 @@ reinstall SPIP in order to recreate a new database and the first administrator\'
 'texte_login_precaution' => 'Warning! This is the login with which you are connected now.
 	Use this form with caution...',
 'texte_message_edit' => 'Warning: this message can be modified by all the site administrators, and it appears to all editors. Use the announcements only to stress important events in the site\'s life.',
-'texte_messagerie_agenda' => 'A messaging system allows the authors of the site to communicate directly in the editing area of the site. It is linked to a calendar.',
+'texte_messagerie_agenda' => 'A messaging system allows the authors of the site to communicate directly in the site\'s private area. It is linked to a calendar.',
 'texte_messages_publics' => 'Public Messages of the article:',
 'texte_mise_a_niveau_base_1' => 'You have just updated SPIP files.
 	Now you must upgrade the site\'s
@@ -1180,10 +1170,10 @@ you can perform searches on sites and
 'titre_compacter_script_css' => 'Compression of scripts and CSS',
 'titre_compresser_flux_http' => 'Compression of HTTP data',
 'titre_config_contenu_notifications' => 'Notifications',
-'titre_config_contenu_prive' => 'In the editing area',
+'titre_config_contenu_prive' => 'In the private area',
 'titre_config_contenu_public' => 'On the public site',
 'titre_config_fonctions' => 'Site configuration',
-'titre_config_forums_prive' => 'Forums in the editing area',
+'titre_config_forums_prive' => 'Forums in the private area',
 'titre_config_groupe_mots_cles' => 'Configuration of the keyword groups',
 'titre_configuration' => 'Site configuration',
 'titre_conflit_edition' => 'Conflict while editing',
